package cn.com.infosec.asn1.x509.qualified;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERIA5String;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import java.util.Enumeration;

public class BiometricData extends ASN1Encodable {
   TypeOfBiometricData typeOfBiometricData;
   AlgorithmIdentifier hashAlgorithm;
   ASN1OctetString biometricDataHash;
   DERIA5String sourceDataUri;

   public static BiometricData getInstance(Object obj) {
      if (obj != null && !(obj instanceof BiometricData)) {
         if (obj instanceof ASN1Sequence) {
            return new BiometricData(ASN1Sequence.getInstance(obj));
         } else {
            throw new IllegalArgumentException("unknown object in getInstance");
         }
      } else {
         return (BiometricData)obj;
      }
   }

   public BiometricData(ASN1Sequence seq) {
      Enumeration seq1;
      this.typeOfBiometricData = TypeOfBiometricData.getInstance((seq1 = seq.getObjects()).nextElement());
      this.hashAlgorithm = AlgorithmIdentifier.getInstance(seq1.nextElement());
      this.biometricDataHash = ASN1OctetString.getInstance(seq1.nextElement());
      if (seq1.hasMoreElements()) {
         this.sourceDataUri = DERIA5String.getInstance(seq1.nextElement());
      }

   }

   public BiometricData(TypeOfBiometricData typeOfBiometricData, AlgorithmIdentifier hashAlgorithm, ASN1OctetString biometricDataHash, DERIA5String sourceDataUri) {
      this.typeOfBiometricData = typeOfBiometricData;
      this.hashAlgorithm = hashAlgorithm;
      this.biometricDataHash = biometricDataHash;
      this.sourceDataUri = sourceDataUri;
   }

   public BiometricData(TypeOfBiometricData typeOfBiometricData, AlgorithmIdentifier hashAlgorithm, ASN1OctetString biometricDataHash) {
      this.typeOfBiometricData = typeOfBiometricData;
      this.hashAlgorithm = hashAlgorithm;
      this.biometricDataHash = biometricDataHash;
      this.sourceDataUri = null;
   }

   public TypeOfBiometricData getTypeOfBiometricData() {
      return this.typeOfBiometricData;
   }

   public AlgorithmIdentifier getHashAlgorithm() {
      return this.hashAlgorithm;
   }

   public ASN1OctetString getBiometricDataHash() {
      return this.biometricDataHash;
   }

   public DERIA5String getSourceDataUri() {
      return this.sourceDataUri;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.typeOfBiometricData);
      var1.add(this.hashAlgorithm);
      var10001.add(this.biometricDataHash);
      DERIA5String var2;
      if ((var2 = this.sourceDataUri) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
